# Variablz Utils Library

[![PyPI Version](https://img.shields.io/pypi/v/variablz-utils.svg)](https://pypi.org/project/variablz/)

Welcome to the Variablz Qt Library! This library provides a collection of utility functions tailored for both software developers using PyQt libraries and data science/machine learning engineers. It's designed to simplify common tasks, enhance productivity, and facilitate learning, especially for students at Variablz Academy.

## Installation

You can easily install the Variablz Library using pip:

```bash
pip install variablz_qt
```



## Features

### PyQt Helpers
#### Table:
Utilize the table function to generate PyQT Table